##  Searching and Filtering
The search field in the navigation bar helps you quickly find a specific fact sheet. As you type, suggested fact sheets appear in the drop-down list, allowing you to select and jump straight to the desired fact sheet. The full-text search capability also allows you to search for and list all fact sheets containing the searched term.
Clicking on the Add Filter button opens the smart search overlay. In the smart search overlay, you can do full-text searches, search and apply filters, as well as jump straight to a desired fact sheet by selecting it from the suggestions.
![Search Field in the Navigation Bar and the Add Filter Button for Smart Search](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27470b397a44101498a19486e0f9d863_LowRes.png)
Search Field in the Navigation Bar and the Add Filter Button for Smart Search
